@@ -23,3 +23,9 @@ globals().update(conf.build_config(
         r'lc_celery_beat.migrations.*',
     ],
 ))
+
+intersphinx_mapping = globals().get('intersphinx_mapping', {})
+intersphinx_mapping['celery'] = (
+    'https://celery.readthedocs.io/en/main/', None)
+globals().update({'intersphinx_mapping': intersphinx_mapping})
+
