@@ -8,6 +8,7 @@ from django.db.models import Case, Value, When
 from django.forms.widgets import Select
 from django.template.defaultfilters import pluralize
 from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from kombu.utils.json import loads
 
 from .models import (
@@ -108,6 +109,7 @@ class PeriodicTaskForm(forms.ModelForm):
         return self._clean_json('kwargs')
 
 
+@admin.register(PeriodicTask)
 class PeriodicTaskAdmin(admin.ModelAdmin):
     """Admin-interface for periodic tasks."""
 
@@ -148,7 +150,24 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
             }
         ),
     )
-    readonly_fields = ('last_run_at',)
+    readonly_fields = (
+        'last_run_at',
+        'crontab_translation',
+    )
+
+    def crontab_translation(self, obj):
+        return obj.crontab.human_readable
+
+    change_form_template = 'admin/lc_celery_beat/change_periodictask_form.html'
+
+    def changeform_view(self, request, object_id=None, form_url='', extra_context=None):
+        extra_context = extra_context or {}
+        crontabs = CrontabSchedule.objects.all()
+        crontab_dict = {}
+        for crontab in crontabs:
+            crontab_dict[crontab.id] = crontab.human_readable
+        extra_context['readable_crontabs'] = crontab_dict
+        return super().changeform_view(request, object_id, extra_context=extra_context)
 
     def changelist_view(self, request, extra_context=None):
         extra_context = extra_context or {}
@@ -160,35 +179,29 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
         qs = super().get_queryset(request)
         return qs.prefetch_related('schedule_object')
 
-    def _message_user_about_update(self, request, rows_updated, verb):
-        """Send message about action to user.
-
-        `verb` should shortly describe what have changed (e.g. 'enabled').
-
-        """
-        self.message_user(
-            request,
-            _('{0} task{1} {2} successfully {3}').format(
-                rows_updated,
-                pluralize(rows_updated),
-                pluralize(rows_updated, _('was,were')),
-                verb,
-            ),
-        )
-
+    @admin.action(description=_('Enable selected tasks'))
     def enable_tasks(self, request, queryset):
         rows_updated = queryset.update(is_active=True)
         PeriodicTasks.update_changed()
-        self._message_user_about_update(request, rows_updated, 'enabled')
-
-    enable_tasks.short_description = _('Enable selected tasks')
+        self.message_user(
+            request,
+            ngettext_lazy(
+                '{0} task was successfully is_active', '{0} tasks were successfully is_active',
+                rows_updated
+            ).format(rows_updated)
+        )
 
+    @admin.action(description=_('Disable selected tasks'))
     def disable_tasks(self, request, queryset):
         rows_updated = queryset.update(is_active=False, last_run_at=None)
         PeriodicTasks.update_changed()
-        self._message_user_about_update(request, rows_updated, 'disabled')
-
-    disable_tasks.short_description = _('Disable selected tasks')
+        self.message_user(
+            request,
+            ngettext_lazy(
+                '{0} task was successfully disabled', '{0} tasks were successfully disabled',
+                rows_updated
+            ).format(rows_updated)
+        )
 
     def _toggle_tasks_activity(self, queryset):
         return queryset.update(
@@ -198,19 +211,25 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
             )
         )
 
+    @admin.action(description=_('Toggle activity of selected tasks'))
     def toggle_tasks(self, request, queryset):
         rows_updated = self._toggle_tasks_activity(queryset)
         PeriodicTasks.update_changed()
-        self._message_user_about_update(request, rows_updated, 'toggled')
-
-    toggle_tasks.short_description = _('Toggle activity of selected tasks')
+        self.message_user(
+            request,
+            ngettext_lazy(
+                '{0} task was successfully toggled', '{0} tasks were successfully toggled',
+                rows_updated
+            ).format(rows_updated)
+        )
 
+    @admin.action(description=_('Run selected tasks'))
     def run_tasks(self, request, queryset):
         self.celery_app.loader.import_default_modules()
-        tasks = [
-            (self.celery_app.tasks.get(task.task), task.args, task.kwargs, task.queue, task.name)
-            for task in queryset
-        ]
+        tasks = [(
+            self.celery_app.tasks.get(task.task), loads(task.args), loads(task.kwargs), task.queue,
+            task.name
+        ) for task in queryset]
 
         if any(t[0] is None for t in tasks):
             for i, t in enumerate(tasks):
@@ -222,7 +241,7 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
 
             self.message_user(
                 request,
-                _('task "{0}" not found'.format(not_found_task_name)),
+                _(f'task "{not_found_task_name}" not found'),
                 level=messages.ERROR,
             )
             return
@@ -246,7 +265,7 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
 
     run_tasks.short_description = _('Run selected tasks')
 
-
+@admin.register(ClockedSchedule)
 class ClockedScheduleAdmin(admin.ModelAdmin):
     """Admin-interface for clocked schedules."""
 
@@ -254,14 +273,25 @@ class ClockedScheduleAdmin(admin.ModelAdmin):
     list_display = ('clocked_time',)
 
 
+@admin.register(CrontabSchedule)
 class CrontabScheduleAdmin(admin.ModelAdmin):
     """Admin class for CrontabSchedule."""
 
-    list_display = ('__str__',)
+    list_display = ('__str__', 'human_readable')
+    fields = (
+        'human_readable', 'minute', 'hour', 'day_of_month', 'month_of_year', 'day_of_week',
+        'timezone'
+    )
+    readonly_fields = ('human_readable',)
 
 
-admin.site.register(IntervalSchedule)
-admin.site.register(CrontabSchedule, CrontabScheduleAdmin)
-admin.site.register(SolarSchedule)
-admin.site.register(ClockedSchedule, ClockedScheduleAdmin)
-admin.site.register(PeriodicTask, PeriodicTaskAdmin)
+@admin.register(SolarSchedule)
+class SolarScheduleAdmin(admin.ModelAdmin):
+    """Admin class for SolarSchedule."""
+    pass
+
+
+@admin.register(IntervalSchedule)
+class IntervalScheduleAdmin(admin.ModelAdmin):
+    """Admin class for IntervalSchedule."""
+    pass
