@@ -351,8 +351,10 @@ class CrontabSchedule(BaseScheduleModel):
         max_length=64,
         default='*',
         verbose_name=_('Day(s) Of The Week'),
-        help_text=_('Cron Days Of The Week to Run. Use "*" for "all". '
-                    '(Example: "0,5")'),
+        help_text=_(
+            'Cron Days Of The Week to Run. Use "*" for "all", Sunday '
+            'is 0 or 7, Monday is 1. (Example: "0,5")'
+        ),
         validators=[validators.day_of_week_validator],
     )
     day_of_month = models.CharField(
@@ -399,6 +401,10 @@ class CrontabSchedule(BaseScheduleModel):
             ),
         ]
 
+    @property
+    def human_readable(self):
+        return self.__str__()
+
     def __str__(self):
         return (
             f'{cronexp(self.minute)} {cronexp(self.hour)} '
