@@ -119,6 +119,9 @@ class SchedulerCase:
         content_type = ContentType.objects.get_for_model(schedule)
         return schedule, content_type
 
+    def create_crontab_schedule(self):
+        return CrontabSchedule.objects.create()
+
 
 @pytest.mark.django_db()
 class test_ModelEntry(SchedulerCase):
@@ -163,7 +166,7 @@ class test_ModelEntry(SchedulerCase):
         os.environ["TZ"] = "Europe/Berlin"
         if hasattr(time, "tzset"):
             time.tzset()
-        assert self.app.timezone.zone == 'Europe/Berlin'
+        assert self.app.timezone.key == 'Europe/Berlin'
 
         # simulate last_run_at from DB - not TZ aware but localtime
         right_now = datetime.utcnow()
@@ -192,7 +195,7 @@ class test_ModelEntry(SchedulerCase):
         os.environ["TZ"] = "Europe/Berlin"
         if hasattr(time, "tzset"):
             time.tzset()
-        assert self.app.timezone.zone == 'Europe/Berlin'
+        assert self.app.timezone.key == 'Europe/Berlin'
         # simulate last_run_at from DB - not TZ aware but localtime
         right_now = datetime.utcnow()
         # make sure to use fixed date time
@@ -226,7 +229,7 @@ class test_ModelEntry(SchedulerCase):
         os.environ["TZ"] = "Europe/Berlin"
         if hasattr(time, "tzset"):
             time.tzset()
-        assert self.app.timezone.zone == 'America/New_York'
+        assert self.app.timezone.key == 'America/New_York'
 
         # simulate last_run_at all none, doing the same thing that
         # _default_now() would do
@@ -348,6 +351,16 @@ class test_DatabaseSchedulerFromAppConf(SchedulerCase):
         assert 'celery.backend_cleanup' in sched
         assert self.entry_name not in sched
 
+    def test_periodic_task_model_schedule_type_change(self):
+        self.m1.interval = None
+        self.m1.crontab = self.create_crontab_schedule()
+        self.m1.save()
+
+        self.Scheduler(app=self.app)
+        self.m1.refresh_from_db()
+        assert self.m1.interval
+        assert self.m1.crontab is None
+
 
 @pytest.mark.django_db()
 class test_DatabaseScheduler(SchedulerCase):
@@ -434,6 +447,28 @@ class test_DatabaseScheduler(SchedulerCase):
         assert self.s.flushed == 1
         assert self.m2.name in self.s._dirty
 
+    def test_sync_not_saves_last_run_at_while_schedule_changed(self):
+        # Update e1 last_run_at and add to dirty
+        e1 = self.s.schedule[self.m2.name]
+        time.sleep(3)
+        e1.model.last_run_at = e1._default_now()
+        self.s._dirty.add(e1.model.name)
+
+        # Record e1 pre sync last_run_at
+        e1_pre_sync_last_run_at = e1.model.last_run_at
+
+        # Set schedule_changed() == True
+        self.s._last_timestamp = monotonic()
+        # Do sync
+        self.s.sync()
+
+        # Record e1 post sync last_run_at
+        e1_m = PeriodicTask.objects.get(pk=e1.model.pk)
+        e1_post_sync_last_run_at = e1_m.last_run_at
+
+        # Check
+        assert e1_pre_sync_last_run_at == e1_post_sync_last_run_at
+
     def test_sync_saves_last_run_at(self):
         e1 = self.s.schedule[self.m2.name]
         last_run = e1.last_run_at
@@ -589,6 +624,29 @@ class test_DatabaseScheduler(SchedulerCase):
     #                 s.sync()
     #     assert len(tried) == 1 and tried == set([e1.name])
 
+    def test_starttime_trigger(self, monkeypatch):
+        # Ensure there is no heap block in case of new task with start_time
+        PeriodicTask.objects.all().delete()
+        s = self.Scheduler(app=self.app)
+        assert not s._heap
+        m1 = self.create_model_interval(schedule(timedelta(seconds=3)))
+        m1.save()
+        s.tick()
+        assert len(s._heap) == 2
+        m2 = self.create_model_interval(
+            schedule(timedelta(days=1)),
+            start_time=make_aware(datetime.now() + timedelta(seconds=2))
+        )
+        m2.save()
+        s.tick()
+        assert s._heap[0][2].name == m2.name
+        assert len(s._heap) == 3
+        assert s._heap[0]
+        time.sleep(2)
+        s.tick()
+        assert s._heap[0]
+        assert s._heap[0][2].name == m1.name
+
 
 @pytest.mark.django_db()
 class test_models(SchedulerCase):
